"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _utils = require("../lib/utils");
var _color = require("../style/color");
var _border = require("../style/border");
var _zIndex = require("../style/zIndex");
var _Text = _interopRequireDefault(require("../Text"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
var arrowHeight = 14;
var arrowWidth = 8;
var ArrowPopover = function ArrowPopover(_ref) {
  var children = _ref.children,
    visible = _ref.visible,
    offset = _ref.offset,
    oneLine = _ref.oneLine,
    position = _ref.position,
    padded = _ref.padded,
    color = _ref.color,
    backgroundColor = _ref.backgroundColor,
    shadow = _ref.shadow,
    width = _ref.width,
    isTooltip = _ref.isTooltip,
    id = _ref.id;
  var offsetTop = position === 'above' ? -offset.top : offset.top;
  var style = (0, _utils.calculateStyles)({
    "default": {
      transform: "translate(".concat(arrowWidth + offset.left, "px, ").concat(offsetTop, "px)"),
      background: (0, _utils.parseColor)(backgroundColor),
      color: (0, _utils.parseColor)(color),
      display: 'inline-block',
      borderRadius: _border.borderRadius,
      boxShadow: shadow ? '0 1px 2px 0 rgba(0,0,0,0.50)' : 'none',
      textAlign: 'left',
      position: 'absolute',
      left: '100%',
      zIndex: _zIndex.tooltip
    },
    hidden: {
      display: 'none'
    },
    oneLine: {
      whiteSpace: 'nowrap'
    },
    positionAbove: {
      bottom: 0
    },
    positionBelow: {
      top: 0
    },
    padded: {
      padding: '.25rem .75rem'
    },
    fixedWidth: {
      width: width
    }
  }, {
    hidden: !visible,
    positionAbove: position === 'above',
    positionBelow: position === 'below',
    oneLine: oneLine && width === 'none',
    padded: padded,
    fixedWidth: width !== 'none'
  });
  var arrowStyle = (0, _utils.calculateStyles)({
    "default": {
      position: 'absolute',
      left: -arrowWidth,
      width: 0,
      height: 0,
      backgroundColor: 'transparent',
      borderStyle: 'solid',
      borderTopWidth: arrowHeight / 2.0,
      borderRightWidth: arrowWidth,
      borderBottomWidth: arrowHeight / 2.0,
      borderLeftWidth: 0,
      borderTopColor: 'transparent',
      borderRightColor: backgroundColor,
      borderBottomColor: 'transparent',
      borderLeftColor: 'transparent'
    },
    positionNormal: {
      top: '50%',
      transform: 'translate(0, -50%)'
    },
    positionAbove: {
      top: 'none',
      bottom: '6px',
      transform: 'none'
    },
    positionBelow: {
      top: '6px',
      transform: 'none'
    }
  }, {
    positionNormal: true,
    positionAbove: position === 'above',
    positionBelow: position === 'below'
  });
  var aria = isTooltip ? {
    role: 'tooltip',
    'aria-hidden': !visible
  } : {};
  return /*#__PURE__*/_react["default"].createElement("div", _extends({
    style: style,
    id: id
  }, aria), /*#__PURE__*/_react["default"].createElement("span", {
    style: arrowStyle
  }), /*#__PURE__*/_react["default"].createElement(_Text["default"], {
    color: color,
    size: "small"
  }, children));
};
ArrowPopover.propTypes = {
  children: _propTypes["default"].node.isRequired,
  visible: _propTypes["default"].bool,
  oneLine: _propTypes["default"].bool,
  offset: _propTypes["default"].shape({
    top: _propTypes["default"].number,
    left: _propTypes["default"].number
  }),
  position: _propTypes["default"].oneOf(['above', 'below', 'none']),
  padded: _propTypes["default"].bool,
  color: _propTypes["default"].string,
  backgroundColor: _propTypes["default"].string,
  shadow: _propTypes["default"].bool,
  width: _propTypes["default"].string,
  isTooltip: _propTypes["default"].bool,
  id: _propTypes["default"].string
};
ArrowPopover.defaultProps = {
  visible: false,
  oneLine: true,
  offset: {
    left: 0,
    top: 0
  },
  position: 'none',
  padded: true,
  color: 'white',
  backgroundColor: _color.darkPopover,
  shadow: false,
  width: 'none',
  isTooltip: false,
  id: ''
};
var _default = ArrowPopover;
exports["default"] = _default;