"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _utils = require("../lib/utils");
var _font = require("../style/font");
var _color = require("../style/color");
var _border = require("../style/border");
var _animation = require("../style/animation");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
var Button = function Button(_ref) {
  var borderless = _ref.borderless,
    children = _ref.children,
    disabled = _ref.disabled,
    focused = _ref.focused,
    hovered = _ref.hovered,
    fillContainer = _ref.fillContainer,
    large = _ref.large,
    onClick = _ref.onClick,
    onMouseEnter = _ref.onMouseEnter,
    onMouseLeave = _ref.onMouseLeave,
    onFocus = _ref.onFocus,
    onBlur = _ref.onBlur,
    secondary = _ref.secondary,
    small = _ref.small,
    tertiary = _ref.tertiary,
    quaternary = _ref.quaternary,
    warning = _ref.warning,
    noStyle = _ref.noStyle,
    label = _ref.label,
    linkStyle = _ref.linkStyle,
    type = _ref.type;
  var style = (0, _utils.calculateStyles)({
    "default": {
      display: 'inline-block',
      margin: '0',
      padding: '0.5rem 2rem',
      fontFamily: _font.fontFamily,
      fontSize: _font.fontSizeSmall,
      fontWeight: _font.fontWeight,
      color: _color.white,
      backgroundColor: _color.curiousBlue,
      border: "".concat(_border.borderWidth, " solid ").concat(_color.transparent),
      borderRadius: '2rem',
      cursor: 'pointer',
      outline: 'none',
      transition: "background-color ".concat(_animation.transitionAnimationTime, " ").concat(_animation.transitionAnimationType)
    },
    hovered: {
      color: _color.white,
      textDecoration: 'none',
      backgroundColor: _color.denim
    },
    disabled: {
      opacity: 0.3
    },
    borderless: {
      color: _color.curiousBlue,
      backgroundColor: _color.transparent,
      border: 0
    },
    borderlessHovered: {
      color: _color.denim,
      backgroundColor: _color.transparent
    },
    large: {
      padding: '0.5rem 2rem',
      fontSize: _font.fontSize
    },
    secondary: {
      color: _color.curiousBlue,
      backgroundColor: _color.transparent,
      borderColor: _color.curiousBlue
    },
    secondaryHovered: {
      color: _color.denim,
      backgroundColor: _color.transparent,
      borderColor: _color.denim
    },
    small: {
      padding: '0.25rem 2rem'
    },
    tertiary: {
      color: _color.outerSpace,
      backgroundColor: _color.transparent,
      borderColor: _color.geyser
    },
    tertiaryHovered: {
      color: _color.outerSpace,
      backgroundColor: _color.transparent
    },
    quaternary: {
      color: _color.outerSpace,
      backgroundColor: _color.offWhite,
      borderColor: _color.geyser
    },
    quaternaryHovered: {
      color: _color.outerSpace,
      backgroundColor: _color.offWhite
    },
    warning: {
      color: _color.outerSpace,
      backgroundColor: _color.transparent,
      borderColor: _color.torchRed
    },
    warningHovered: {
      color: _color.white,
      backgroundColor: _color.torchRed
    },
    fillContainer: {
      width: '100%'
    },
    noStyle: {
      display: 'unset',
      lineHeight: 'unset',
      margin: 'unset',
      padding: 0,
      fontFamily: 'unset',
      fontSize: 'unset',
      fontWeight: 'unset',
      color: 'unset',
      backgroundColor: 'unset',
      background: 'none',
      border: 'none',
      borderRadius: 'unset',
      outline: 'none',
      transition: 'unset'
    },
    linkStyle: {
      background: 'none',
      backgroundColor: 'unset',
      border: 'none',
      color: _color.curiousBlue,
      padding: 0,
      display: 'block',
      margin: '0 auto',
      borderRadius: 'unset'
    },
    focused: {
      boxShadow: "0 0 0.25rem ".concat(_color.curiousBlue)
    }
  }, {
    disabled: disabled && !noStyle,
    hovered: hovered && !noStyle && !disabled,
    borderless: borderless,
    borderlessHovered: borderless && hovered && !disabled,
    large: large,
    secondary: secondary,
    secondaryHovered: secondary && hovered && !disabled,
    small: small,
    tertiary: tertiary,
    tertiaryHovered: tertiary && hovered && !disabled,
    quaternary: quaternary,
    quaternaryHovered: quaternary && hovered && !disabled,
    warning: warning,
    warningHovered: warning && hovered && !disabled,
    fillContainer: fillContainer,
    noStyle: noStyle,
    focused: focused,
    linkStyle: linkStyle
  });
  return /*#__PURE__*/_react["default"].createElement("button", {
    style: style,
    onClick: onClick,
    onMouseEnter: onMouseEnter,
    onMouseLeave: onMouseLeave,
    onFocus: onFocus,
    onBlur: onBlur,
    disabled: disabled,
    "aria-label": label || null,
    type: type
  }, children);
};
Button.propTypes = {
  children: _propTypes["default"].node,
  borderless: _propTypes["default"].bool,
  disabled: _propTypes["default"].bool,
  fillContainer: _propTypes["default"].bool,
  focused: _propTypes["default"].bool,
  hovered: _propTypes["default"].bool,
  large: _propTypes["default"].bool,
  noStyle: _propTypes["default"].bool,
  onClick: _propTypes["default"].func,
  onMouseEnter: _propTypes["default"].func,
  onMouseLeave: _propTypes["default"].func,
  onFocus: _propTypes["default"].func,
  onBlur: _propTypes["default"].func,
  secondary: _propTypes["default"].bool,
  small: _propTypes["default"].bool,
  tertiary: _propTypes["default"].bool,
  quaternary: _propTypes["default"].bool,
  warning: _propTypes["default"].bool,
  label: _propTypes["default"].string,
  linkStyle: _propTypes["default"].bool,
  type: _propTypes["default"].oneOf(['button', 'submit', 'reset'])
};
var _default = Button;
exports["default"] = _default;