"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _utils = require("../lib/utils");
var _font = require("../style/font");
var _color = require("../style/color");
var _border = require("../style/border");
var _animation = require("../style/animation");
var _dropShadow = require("../style/dropShadow");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
var Card = function Card(_ref) {
  var children = _ref.children,
    backgroundColor = _ref.backgroundColor,
    borderColor = _ref.borderColor,
    doublePadding = _ref.doublePadding,
    empty = _ref.empty,
    faded = _ref.faded,
    failed = _ref.failed,
    hovered = _ref.hovered,
    noBorder = _ref.noBorder,
    noPadding = _ref.noPadding,
    onMouseEnter = _ref.onMouseEnter,
    onMouseLeave = _ref.onMouseLeave,
    reducedPadding = _ref.reducedPadding,
    shadowHeight = _ref.shadowHeight,
    draggingPlaceholder = _ref.draggingPlaceholder,
    className = _ref.className;
  var style = (0, _utils.calculateStyles)({
    "default": {
      padding: '1.5rem',
      fontSize: _font.fontSizeMini,
      lineHeight: _font.lineHeight,
      backgroundColor: _color.white,
      border: "".concat(_border.borderWidth, " solid ").concat(_color.mystic),
      borderRadius: _border.borderRadius,
      transition: "box-shadow ".concat(_animation.transitionAnimationTime, " ").concat(_animation.transitionAnimationType)
    },
    doublePadding: {
      padding: '3rem'
    },
    empty: {
      borderColor: _color.geyser,
      borderStyle: 'dashed'
    },
    failed: {
      borderColor: _color.torchRed
    },
    faded: {
      opacity: 0.5
    },
    noBorder: {
      border: "".concat(_border.borderWidth, " solid transparent")
    },
    noPadding: {
      padding: 0
    },
    hovered: {
      boxShadow: _dropShadow.boxShadowLevelOne
    },
    backgroundColor: {
      backgroundColor: backgroundColor
    },
    borderColor: {
      borderColor: borderColor
    },
    reducedPadding: {
      padding: '1rem'
    },
    shadowHeightOne: {
      boxShadow: _dropShadow.boxShadowLevelOne
    },
    shadowHeightTwo: {
      boxShadow: _dropShadow.boxShadowLevelTwo
    },
    draggingPlaceholder: {
      border: "".concat(_border.borderWidth, " dashed ").concat(_color.outerSpaceLight)
    }
  }, {
    doublePadding: doublePadding,
    empty: empty,
    failed: failed,
    faded: faded,
    noBorder: noBorder,
    noPadding: noPadding,
    hovered: hovered,
    backgroundColor: backgroundColor,
    borderColor: borderColor,
    reducedPadding: reducedPadding,
    shadowHeightOne: shadowHeight === 1,
    shadowHeightTwo: shadowHeight === 2,
    draggingPlaceholder: draggingPlaceholder
  });
  return /*#__PURE__*/_react["default"].createElement("div", {
    style: style,
    className: className,
    onMouseEnter: onMouseEnter,
    onMouseLeave: onMouseLeave
  }, children);
};
Card.propTypes = {
  children: _propTypes["default"].node,
  backgroundColor: _propTypes["default"].string,
  borderColor: _propTypes["default"].string,
  doublePadding: _propTypes["default"].bool,
  empty: _propTypes["default"].bool,
  faded: _propTypes["default"].bool,
  failed: _propTypes["default"].bool,
  hovered: _propTypes["default"].bool,
  noBorder: _propTypes["default"].bool,
  noPadding: _propTypes["default"].bool,
  onMouseEnter: _propTypes["default"].func,
  onMouseLeave: _propTypes["default"].func,
  reducedPadding: _propTypes["default"].bool,
  shadowHeight: _propTypes["default"].oneOf([0, 1, 2]),
  draggingPlaceholder: _propTypes["default"].bool,
  className: _propTypes["default"].string
};
Card.defaultProps = {
  shadowHeight: 0,
  draggingPlaceholder: false
};
var _default = Card;
exports["default"] = _default;