"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _react = _interopRequireDefault(require("react"));
var _uuid = _interopRequireDefault(require("uuid"));
var _reactAutocomplete = _interopRequireDefault(require("react-autocomplete"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _Text = _interopRequireDefault(require("../Text"));
var _utils = require("../lib/utils");
var _color = require("../style/color");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
var matchValueToItem = function matchValueToItem(item, value) {
  return item.label.toLowerCase().indexOf(value.toLowerCase()) !== -1;
};
var InputAutocomplete = function InputAutocomplete(_ref) {
  var _ref$input = _ref.input,
    value = _ref$input.value,
    onChange = _ref$input.onChange,
    _onSelect = _ref.onSelect,
    items = _ref.items,
    sortItems = _ref.sortItems,
    placeholder = _ref.placeholder,
    onFocusHandler = _ref.onFocusHandler,
    onBlurHandler = _ref.onBlurHandler,
    disabled = _ref.disabled;
  var renderItem = function renderItem(_ref2, isHighlighted) {
    var label = _ref2.label;
    var style = (0, _utils.calculateStyles)({
      "default": {
        padding: '2px 6px',
        cursor: 'default',
        display: 'block',
        position: 'relative'
      },
      isHighlighted: {
        color: 'white',
        background: "".concat(_color.aquaHaze),
        padding: '2px 6px',
        cursor: 'default'
      }
    }, {
      isHighlighted: isHighlighted
    });
    return /*#__PURE__*/_react["default"].createElement("div", {
      style: style
    }, /*#__PURE__*/_react["default"].createElement(_Text["default"], {
      key: (0, _uuid["default"])()
    }, label));
  };
  var inputStyle = {
    margin: '0 0 0 0',
    padding: '.5rem',
    fontSize: '.8rem',
    backgroundColor: '#fff',
    border: '1px solid #e6ebef',
    borderRadius: '2px',
    width: '100%'
  };
  var notEmpty = items.length > 1;
  var menuStyle = (0, _utils.calculateStyles)({
    "default": {
      margin: '0.25rem 0 0 0',
      backgroundColor: "".concat(_color.white),
      position: 'absolute'
    },
    notEmpty: {
      margin: '0.25rem 0 0 0',
      backgroundColor: "".concat(_color.white),
      border: '1px solid #e6ebef',
      borderRadius: '2px',
      boxShadow: '0 1px 2px rgba(50, 59, 67, 0.3)',
      position: 'absolute',
      zIndex: '3000'
    }
  }, {
    notEmpty: notEmpty
  });
  var wrapperStyle = {
    display: 'flex',
    width: '100%'
  };
  return /*#__PURE__*/_react["default"].createElement("div", null, /*#__PURE__*/_react["default"].createElement(_reactAutocomplete["default"], {
    value: value,
    inputProps: {
      id: 'states-autocomplete',
      style: inputStyle,
      placeholder: placeholder,
      onFocus: onFocusHandler,
      onBlur: onBlurHandler,
      disabled: disabled
    },
    items: items,
    getItemValue: function getItemValue(item) {
      return item.label;
    },
    shouldItemRender: matchValueToItem,
    sortItems: sortItems,
    onChange: onChange,
    onSelect: function onSelect(val, obj) {
      value = val;
      _onSelect(obj);
    },
    renderItem: renderItem,
    menuStyle: menuStyle,
    wrapperStyle: wrapperStyle
  }));
};
InputAutocomplete.propTypes = {
  input: _propTypes["default"].shape({
    onChange: _propTypes["default"].func.isRequired,
    value: _propTypes["default"].string.isRequired
  }).isRequired,
  items: _propTypes["default"].arrayOf(_propTypes["default"].shape({
    label: _propTypes["default"].string.isRequired
  })).isRequired,
  onSelect: _propTypes["default"].func.isRequired,
  sortItems: _propTypes["default"].func.isRequired,
  onFocusHandler: _propTypes["default"].func.isRequired,
  placeholder: _propTypes["default"].string,
  onBlurHandler: _propTypes["default"].func.isRequired,
  disabled: _propTypes["default"].bool
};
InputAutocomplete.defaultProps = {
  value: '',
  items: [],
  placeholder: '',
  disabled: false
};
var _default = InputAutocomplete;
exports["default"] = _default;