"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _font = require("../style/font");
var _color = require("../style/color");
var _reactDayPicker = _interopRequireDefault(require("react-day-picker"));
var _InputDateNavBar = _interopRequireDefault(require("./InputDateNavBar"));
var _InputDateWeekday = _interopRequireDefault(require("./InputDateWeekday"));
var _InputDateCaption = _interopRequireDefault(require("./InputDateCaption"));
var _Text = _interopRequireDefault(require("../Text"));
var _moment = _interopRequireDefault(require("moment"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
/* eslint-disable react/prop-types */
var datepickerStyles = {
  display: 'flex',
  flexWrap: 'wrap',
  justifyContent: 'center',
  position: 'relative',
  userSelect: 'none',
  fontFamily: _font.fontFamily,
  minWidth: '336px'
};
var modifierStyles = {
  cell: {
    display: 'inline-block',
    padding: '.6rem 0rem',
    width: '3rem',
    textAlign: 'center',
    cursor: 'pointer',
    verticalAlign: 'middle',
    overflow: 'hidden',
    color: 'black',
    fontSize: _font.fontSizeMini,
    border: '0.5px solid #eff1f1',
    outline: '0.5px solid #eff1f1',
    boxSizing: 'border-box'
  },
  today: {
    color: _color.curiousBlue
  },
  outside: {
    color: '#dce0e0',
    cursor: 'default'
  },
  disabled: {
    color: '#dce0e0',
    cursor: 'default',
    backgroundColor: '#f8f8f8'
  },
  selected: {
    color: _color.white,
    backgroundColor: _color.outerSpace,
    width: 'calc(100% / 7)'
  }
};
var modifiers = {
  cell: {
    daysOfWeek: [0, 1, 2, 3, 4, 5, 6]
  }
};
var renderError = function renderError(_ref) {
  var error = _ref.error,
    touched = _ref.touched;
  return error && touched ? /*#__PURE__*/_react["default"].createElement("div", {
    style: {
      marginTop: '1rem',
      textAlign: 'center',
      width: '100%'
    }
  }, /*#__PURE__*/_react["default"].createElement(_Text["default"], {
    color: 'torchRed'
  }, error)) : null;
};
var disabledDays = function disabledDays(_ref2, initialMonth) {
  var disableBefore = _ref2.disableBefore,
    submitting = _ref2.submitting;
  if (submitting) {
    return function () {
      return true;
    };
  } else if (disableBefore) {
    return {
      before: new Date(disableBefore.year, disableBefore.month, disableBefore.day)
    };
  }
  return {
    before: initialMonth
  };
};

/* eslint-enable react/prop-types */

var InputDate = function InputDate(_ref3) {
  var disableBefore = _ref3.disableBefore,
    _ref3$input = _ref3.input,
    value = _ref3$input.value,
    onChange = _ref3$input.onChange,
    initialMonthYear = _ref3.initialMonthYear,
    _ref3$meta = _ref3.meta,
    error = _ref3$meta.error,
    touched = _ref3$meta.touched,
    submitting = _ref3$meta.submitting,
    firstDayOfWeek = _ref3.firstDayOfWeek,
    firstMonthToDisplay = _ref3.firstMonthToDisplay,
    onNavigationClick = _ref3.onNavigationClick,
    weekdayLength = _ref3.weekdayLength,
    date = _ref3.date,
    renderDay = _ref3.renderDay,
    _onDayClick = _ref3.onDayClick,
    selectedDays = _ref3.selectedDays,
    initialMonth = _ref3.initialMonth;
  return /*#__PURE__*/_react["default"].createElement("div", {
    style: datepickerStyles
  }, /*#__PURE__*/_react["default"].createElement(_reactDayPicker["default"], {
    navbarElement: /*#__PURE__*/_react["default"].createElement(_InputDateNavBar["default"], {
      firstMonthToDisplay: firstMonthToDisplay,
      onNavigationClick: onNavigationClick
    }),
    weekdayElement: /*#__PURE__*/_react["default"].createElement(_InputDateWeekday["default"], {
      weekdayLength: weekdayLength
    }),
    captionElement: /*#__PURE__*/_react["default"].createElement(_InputDateCaption["default"], {
      date: date
    }),
    className: submitting ? 'disabled' : undefined,
    disabledDays: disabledDays({
      disableBefore: disableBefore,
      submitting: submitting
    }, initialMonth)
    // First month the user can navigate to, default to current month:
    ,
    fromMonth: firstMonthToDisplay
    // Month showed when open the calendar:
    ,
    initialMonth: initialMonthYear ? new Date(initialMonthYear.year, initialMonthYear.month) : initialMonth,
    renderDay: renderDay,
    modifiers: modifiers,
    modifiersStyles: modifierStyles,
    showOutsideDays: true,
    onDayClick: function onDayClick(day, _ref4) {
      var disabled = _ref4.disabled;
      if (!disabled) {
        onChange({
          day: day.getDate(),
          month: day.getMonth(),
          year: day.getFullYear()
        });
        _onDayClick(day);
      }
    },
    selectedDays: selectedDays ? selectedDays : !value ? null : new Date(value.year, value.month, value.day),
    firstDayOfWeek: firstDayOfWeek
  }), renderError({
    error: error,
    touched: touched
  }));
};
InputDate.propTypes = {
  input: _propTypes["default"].shape({
    value: _propTypes["default"].oneOfType([_propTypes["default"].shape({
      day: _propTypes["default"].number,
      month: _propTypes["default"].number,
      year: _propTypes["default"].number
    }), _propTypes["default"].string]),
    onChange: _propTypes["default"].func
  }).isRequired,
  initialMonthYear: _propTypes["default"].shape({
    month: _propTypes["default"].number,
    year: _propTypes["default"].number
  }),
  disableBefore: _propTypes["default"].shape({
    month: _propTypes["default"].number,
    year: _propTypes["default"].number
  }),
  meta: _propTypes["default"].shape({
    error: _propTypes["default"].string,
    touched: _propTypes["default"].bool,
    submitting: _propTypes["default"].bool
  }),
  firstDayOfWeek: _propTypes["default"].oneOf([0, 1, 2, 3, 4, 5, 6]),
  firstMonthToDisplay: _propTypes["default"].instanceOf(Date),
  initialMonth: _propTypes["default"].instanceOf(Date),
  onNavigationClick: _propTypes["default"].func,
  weekdayLength: _propTypes["default"].oneOf(['short', 'medium', 'long']),
  date: _propTypes["default"].instanceOf(Date),
  renderDay: _propTypes["default"].func,
  onDayClick: _propTypes["default"].func
};
InputDate.defaultProps = {
  input: {
    value: '',
    onChange: function onChange() {}
  },
  meta: {},
  firstDayOfWeek: 0,
  firstMonthToDisplay: (0, _moment["default"])().toDate(),
  onNavigationClick: function onNavigationClick() {},
  weekdayLength: 'short',
  onDayClick: function onDayClick() {}
};
var _default = InputDate;
exports["default"] = _default;