"use strict";

var _react = _interopRequireDefault(require("react"));
var _enzyme = require("enzyme");
var _enzymeAdapterReact = _interopRequireDefault(require("enzyme-adapter-react-16"));
var _LinkStateless = _interopRequireDefault(require("../LinkStateless"));
var _index = _interopRequireDefault(require("./index"));
var _a11yTestHelper = _interopRequireDefault(require("../lib/a11yTestHelper"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
(0, _enzyme.configure)({
  adapter: new _enzymeAdapterReact["default"]()
});
describe('Link', function () {
  it('should pass accessibility audit', function () {
    return (0, _a11yTestHelper["default"])( /*#__PURE__*/_react["default"].createElement(_index["default"], {
      href: 'localhost:8000'
    }, "A Link")).then(function (results) {
      return expect(results.violations.length).toBe(0);
    });
  });
  it('should toggle hovered prop when mouseEnter and mouseLeave are triggered', function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_index["default"], {
      href: 'localhost:8000'
    }, "A Link"));
    var link = wrapper.find(_LinkStateless["default"]);
    link.simulate('mouseEnter');
    wrapper.update();
    expect(wrapper.find(_LinkStateless["default"]).props().hovered).toBe(true);
    link.simulate('mouseLeave');
    wrapper.update();
    expect(wrapper.find(_LinkStateless["default"]).props().hovered).toBe(false);
  });
  it('should toggle focused prop when focus and blur are triggered', function () {
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_index["default"], {
      href: 'localhost:8000'
    }, "A Link"));
    var link = wrapper.find(_LinkStateless["default"]);
    link.simulate('focus');
    wrapper.update();
    expect(wrapper.find(_LinkStateless["default"]).props().focused).toBe(true);
    link.simulate('blur');
    wrapper.update();
    expect(wrapper.find(_LinkStateless["default"]).props().focused).toBe(false);
  });
  it('should toggle focused prop when focus and blur are triggered', function () {
    /* eslint-disable react/prop-types */
    var HoverableFocusableThing = function HoverableFocusableThing(_ref) {
      var hovered = _ref.hovered,
        focused = _ref.focused;
      return /*#__PURE__*/_react["default"].createElement("div", null, hovered, " - ", focused);
    };
    /* eslint-enable react/prop-types */
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react["default"].createElement(_index["default"], null, /*#__PURE__*/_react["default"].createElement(HoverableFocusableThing, null)));
    var link = wrapper.find(_LinkStateless["default"]);
    link.simulate('focus');
    wrapper.update();
    expect(wrapper.find(_LinkStateless["default"]).props().focused).toBe(true);
    link.simulate('blur');
    wrapper.update();
    expect(wrapper.find(_LinkStateless["default"]).props().focused).toBe(false);
  });
});