"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _Text = _interopRequireDefault(require("../Text"));
var _Link = _interopRequireDefault(require("../Link"));
var _color = _interopRequireDefault(require("../style/color"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
var linkDataToElement = function linkDataToElement(options, link, key) {
  return /*#__PURE__*/_react["default"].createElement(_Link["default"], {
    href: link.url,
    key: key,
    unstyled: options.unstyled,
    newTab: options.newTab,
    className: link.className
  }, link.displayString);
};
var calulateLinkifiedText = function calulateLinkifiedText(options, links, curString) {
  var calculatedElements = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : [];
  // nothing left to calculate, return all the caluculated pairs
  if (curString && curString.length === 0 || !curString) {
    calculatedElements.reverse();
    return calculatedElements;
  }
  // consume whats left of the string
  if (links && links.length === 0 || !links) {
    calculatedElements.push(curString);
    return calulateLinkifiedText(options, links, '', calculatedElements);
  }
  var lastLink = links[links.length - 1];
  // link is outside of bounds
  if (curString.length <= lastLink.indices[0]) {
    return calulateLinkifiedText(options, links.slice(0, -1), curString, calculatedElements);
  }
  // text at the end that's not a link
  if (curString.length !== lastLink.indices[1]) {
    calculatedElements.push(curString.substring(lastLink.indices[1]));
    return calulateLinkifiedText(options, links, curString.substring(0, lastLink.indices[1]), calculatedElements);
  }
  // found a link!
  calculatedElements.push(linkDataToElement(options, lastLink, calculatedElements.length));
  return calulateLinkifiedText(options, links.slice(0, -1), curString.substring(0, lastLink.indices[0]), calculatedElements);
};
var LinkifiedText = function LinkifiedText(_ref) {
  var children = _ref.children,
    color = _ref.color,
    links = _ref.links,
    newTab = _ref.newTab,
    size = _ref.size,
    unstyled = _ref.unstyled,
    whitespace = _ref.whitespace;
  var options = {
    unstyled: unstyled,
    newTab: newTab
  };
  return /*#__PURE__*/_react["default"].createElement(_Text["default"], {
    whitespace: whitespace,
    size: size,
    color: color
  }, calulateLinkifiedText(options, links, children));
};
LinkifiedText.propTypes = {
  children: _propTypes["default"].string,
  color: _propTypes["default"].oneOf(Object.keys(_color["default"])),
  links: _propTypes["default"].arrayOf(_propTypes["default"].shape({
    rawString: _propTypes["default"].string,
    displayString: _propTypes["default"].string,
    expandedUrl: _propTypes["default"].string,
    indices: _propTypes["default"].arrayOf(_propTypes["default"].number)
  })),
  newTab: _propTypes["default"].bool,
  size: _propTypes["default"].string,
  unstyled: _propTypes["default"].bool,
  whitespace: _propTypes["default"].string
};
LinkifiedText.defaultProps = {
  links: []
};
var _default = LinkifiedText;
exports["default"] = _default;