"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _utils = require("../lib/utils");
var _font = require("../style/font");
var _whiteSpaces = require("../style/whiteSpaces");
var _color = _interopRequireDefault(require("../style/color"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
var Text = function Text(_ref) {
  var children = _ref.children,
    size = _ref.size,
    weight = _ref.weight,
    color = _ref.color,
    whitespace = _ref.whitespace,
    className = _ref.className;
  var style = (0, _utils.calculateStyles)({
    "default": {
      fontFamily: _font.fontFamily,
      fontSize: _font.fontSize,
      fontWeight: _font.fontWeight,
      color: _color["default"][color]
    },
    // Weights
    extraLight: {
      fontWeight: _font.fontWeightExtraLight
    },
    light: {
      fontWeight: _font.fontWeightLight
    },
    thin: {
      fontWeight: _font.fontWeightThin
    },
    medium: {
      fontWeight: _font.fontWeightMedium
    },
    semiBold: {
      fontWeight: _font.fontWeightSemiBold
    },
    bold: {
      fontWeight: _font.fontWeightBold
    },
    extraBold: {
      fontWeight: _font.fontWeightExtraBold
    },
    black: {
      fontWeight: _font.fontWeightBlack
    },
    // Sizes
    extraSmall: {
      fontSize: _font.fontSizeExtraSmall
    },
    large: {
      fontSize: _font.fontSizeLarge
    },
    extraLarge: {
      fontSize: _font.fontSizeExtraLarge
    },
    mini: {
      fontSize: _font.fontSizeMini
    },
    small: {
      fontSize: _font.fontSizeSmall
    },
    preWrap: {
      whiteSpace: _whiteSpaces.preWrap
    },
    normal: {
      whiteSpace: _whiteSpaces.normal
    },
    preLine: {
      whiteSpace: _whiteSpaces.preLine
    },
    pre: {
      whiteSpace: _whiteSpaces.pre
    },
    noWrap: {
      whiteSpace: _whiteSpaces.noWrap
    }
  }, {
    // Weights
    extraLight: weight === 'extra-light',
    light: weight === 'light',
    thin: weight === 'thin',
    medium: weight === 'medium',
    semiBold: weight === 'semi-bold',
    bold: weight === 'bold',
    extraBold: weight === 'extra-bold',
    black: weight === 'black',
    // Sizes
    extraSmall: size === 'extra-small',
    large: size === 'large',
    extraLarge: size === 'extra-large',
    mini: size === 'mini',
    small: size === 'small',
    // White-Space
    preWrap: whitespace === _whiteSpaces.preWrap,
    normal: whitespace === _whiteSpaces.normal,
    preLine: whitespace === _whiteSpaces.preLine,
    pre: whitespace === _whiteSpaces.pre,
    noWrap: whitespace === _whiteSpaces.noWrap
  });
  return /*#__PURE__*/_react["default"].createElement("span", {
    style: style,
    className: className
  }, children);
};
Text.propTypes = {
  children: _propTypes["default"].node,
  size: _propTypes["default"].oneOf(['extra-small', 'large', 'extra-large', 'mini', 'small']),
  weight: _propTypes["default"].oneOf(['extra-light', 'light', 'thin', 'medium', 'semi-bold', 'bold', 'extra-bold', 'black']),
  color: _propTypes["default"].oneOf(Object.keys(_color["default"])),
  whitespace: _propTypes["default"].oneOf(_whiteSpaces.whiteSpaces),
  className: _propTypes["default"].string
};
Text.defaultProps = {
  color: 'shuttleGray'
};
var _default = Text;
exports["default"] = _default;