"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _reactDom = require("react-dom");
var _axeCore = _interopRequireDefault(require("axe-core"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
// Modified from: https://gist.github.com/marcysutton/835c2fd90fadb631414b39523d5bda61

/**
* Report results in a readable fashion.
* @private
* @param {object} results - The aXe [results object](https://github.com/dequelabs/axe-core/blob/master/doc/API.md#results-object).
*/
/* istanbul ignore next */
var report = function report(results) {
  // output some useful information
  var failureNotice = '';
  if (results.violations.length > 0) {
    failureNotice += 'Accessibility violations:\n'; //eslint-disable-line
    results.violations.forEach(function (violation) {
      failureNotice += violation.description + '\n'; //eslint-disable-line
      failureNotice += 'HTML Nodes: \n'; //eslint-disable-line
      violation.nodes.forEach(function (node) {
        failureNotice += node.html + '\n'; //eslint-disable-line
      });
    });

    console.log(failureNotice); //eslint-disable-line
  }
};

/**
* Test a component with Enzyme.
*
* @param {any} app - Your app reference.
* @param {object} config (optional) - An aXe config object to enable/disable rules. See
* [axe.a11yCheck](https://github.com/dequelabs/axe-core/blob/master/doc/API.md#options-parameter).
* @param {function} callback - A callback function to execute when aXe returns.
*/
/* istanbul ignore next */
var testComponentA11y = function testComponentA11y(app) {
  var div = document.createElement('div'); //eslint-disable-line
  document.body.appendChild(div); //eslint-disable-line

  (0, _reactDom.render)(app, div);
  var node = (0, _reactDom.findDOMNode)(div); //eslint-disable-line
  var config = {
    rules: {
      'color-contrast': {
        enabled: false
      }
    }
  };
  document.body.removeChild(div); //eslint-disable-line
  return new Promise(function (resolve) {
    _axeCore["default"].a11yCheck(node, config, function (results) {
      resolve(results);
      report(results);
    });
  });
};
var _default = testComponentA11y;
exports["default"] = _default;